@@ -23,17 +23,17 @@ class GoogleAnalyticsValidator(Validator):
     def get_violation_definitions(cls):
         return {
             'google_analytics.not_found': {
-                'title': 'Google Analytics not found.',
+                'title': 'Google Analytics not found',
                 'description': cls.get_analytics_message,
                 'category': 'SEO'
             },
             'google_analytics.account.not_found': {
-                'title': 'Google Analytics account not found.',
+                'title': 'Google Analytics account not found',
                 'description': cls.get_account_message,
                 'category': 'SEO'
             },
             'google_analytics.domain.not_found': {
-                'title': 'Google Analytics domain not found.',
+                'title': 'Google Analytics domain not found',
                 'description': cls.get_domain_message,
                 'category': 'SEO'
             }
